.. image:: https://travis-ci.org/prefer/camdict.svg?branch=master
    :target: https://travis-ci.org/prefer/camdict
    :alt: Tests

.. image:: https://img.shields.io/coveralls/prefer/camdict.svg?style=flat
    :target: https://coveralls.io/r/prefer/camdict
    :alt: Coverage

.. image:: https://pypip.in/version/camdict/badge.svg?style=flat&text=version
    :target: https://pypi.python.org/pypi/camdict/
    :alt: Latest Version

.. image:: https://pypip.in/py_versions/camdict/badge.svg?style=flat&0
    :target: https://pypi.python.org/pypi/camdict/
    :alt: Supported Python versions

.. image:: https://pypip.in/status/camdict/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/camdict/
    :alt: Development Status

.. image:: https://pypip.in/license/camdict/badge.svg?style=flat
    :target: https://pypi.python.org/pypi/camdict/
    :alt: License

API for `Cambridge Dictionaries Online <http://dictionary.cambridge.org/>`_
--------------------------------

Take a look to the tests for usage examples